# Dora Node for recording data from microphone

This node will send data as soon as the microphone volume is higher than a threshold.

Check example at [examples/speech-to-text](examples/speech-to-text)
